==> seedsui-react-5.5.92.tgz: package/lib/Swiper/Swiper.js <==
var _excluded = ["params", "wrapperAttribute", "paginationAttribute", "prevAttribute", "nextAttribute", "children", "containerChildren"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// require (PrototypeArray.js), 使用了equals
import React, { forwardRef, useRef, useImperativeHandle, useEffect } from 'react'; // eslint-disable-next-line

export default /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$params = _ref.params,
      params = _ref$params === void 0 ? {} : _ref$params,
      _ref$wrapperAttribute = _ref.wrapperAttribute,
      wrapperAttribute = _ref$wrapperAttribute === void 0 ? {} : _ref$wrapperAttribute,
      _ref$paginationAttrib = _ref.paginationAttribute,
      paginationAttribute = _ref$paginationAttrib === void 0 ? {} : _ref$paginationAttrib,
      _ref$prevAttribute = _ref.prevAttribute,
      prevAttribute = _ref$prevAttribute === void 0 ? {} : _ref$prevAttribute,
      _ref$nextAttribute = _ref.nextAttribute,
      nextAttribute = _ref$nextAttribute === void 0 ? {} : _ref$nextAttribute,
      children = _ref.children,
      containerChildren = _ref.containerChildren,
      others = _objectWithoutProperties(_ref, _excluded);

  var rootRef = useRef(null);
  var instance = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      instance: instance.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      },
      getInstance: function getInstance() {
        return instance.current;
      }
    };
  });
  useEffect(function () {
    if (!rootRef || !rootRef.current) return;

    if (!window.Swiper) {
      window.Swiper = require("./instance");

      if (_typeof(window.Swiper) === 'object') {
        window.Swiper = window.Swiper.default;
      }
    }

    instance.current = new window.Swiper(rootRef.current, _objectSpread({}, params));
  }, []); // eslint-disable-line
  // 更新句柄, 防止synchronization模式, 每次组件在render的时候都生成上次render的state、function、effects

  if (instance.current) {
    instance.current.update();

    if (params.on) {
      for (var eventName in params.on) {
        instance.current.off(eventName);
        instance.current.on(eventName, params.on[eventName]);
      }
    }
  }

  return /*#__PURE__*/React.createElement("div", _extends({
    ref: rootRef
  }, others, {
    className: "swiper-container".concat(others.className ? ' ' + others.className : '')
  }), /*#__PURE__*/React.createElement("div", _extends({}, wrapperAttribute, {
    className: "swiper-wrapper".concat(wrapperAttribute.className ? ' ' + wrapperAttribute.className : '')
  }), children), params.pagination && /*#__PURE__*/React.createElement("div", _extends({}, paginationAttribute, {
    className: "swiper-pagination".concat(paginationAttribute.className ? ' ' + paginationAttribute.className : '')
  })), params.navigation && params.navigation.prevEl && /*#__PURE__*/React.createElement("div", _extends({}, prevAttribute, {
    className: "swiper-button-prev".concat(prevAttribute.className ? ' ' + prevAttribute.className : '')
  })), params.navigation && params.navigation.nextEl && /*#__PURE__*/React.createElement("div", _extends({}, nextAttribute, {
    className: "swiper-button-next".concat(nextAttribute.className ? ' ' + nextAttribute.className : '')
  })), containerChildren);
});

==> seedsui-react-5.6.52.tgz: package/lib/Swiper/Swiper.js <==
var _excluded = ["params", "wrapperAttribute", "paginationAttribute", "prevAttribute", "nextAttribute", "children", "containerChildren"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// require (PrototypeArray.js), 使用了equals
import React, { forwardRef, useRef, useImperativeHandle, useEffect } from 'react'; // eslint-disable-next-line

export default /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$params = _ref.params,
      params = _ref$params === void 0 ? {} : _ref$params,
      _ref$wrapperAttribute = _ref.wrapperAttribute,
      wrapperAttribute = _ref$wrapperAttribute === void 0 ? {} : _ref$wrapperAttribute,
      _ref$paginationAttrib = _ref.paginationAttribute,
      paginationAttribute = _ref$paginationAttrib === void 0 ? {} : _ref$paginationAttrib,
      _ref$prevAttribute = _ref.prevAttribute,
      prevAttribute = _ref$prevAttribute === void 0 ? {} : _ref$prevAttribute,
      _ref$nextAttribute = _ref.nextAttribute,
      nextAttribute = _ref$nextAttribute === void 0 ? {} : _ref$nextAttribute,
      children = _ref.children,
      containerChildren = _ref.containerChildren,
      others = _objectWithoutProperties(_ref, _excluded);

  var rootRef = useRef(null);
  var instance = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      instance: instance.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      },
      getInstance: function getInstance() {
        return instance.current;
      }
    };
  });
  useEffect(function () {
    if (!rootRef || !rootRef.current) return;

    if (!window.Swiper) {
      window.Swiper = require("./instance");

      if (_typeof(window.Swiper) === 'object') {
        window.Swiper = window.Swiper.default;
      }
    }

    instance.current = new window.Swiper(rootRef.current, _objectSpread({}, params));
  }, []); // eslint-disable-line
  // 更新句柄, 防止synchronization模式, 每次组件在render的时候都生成上次render的state、function、effects

  if (instance.current) {
    instance.current.update();

    if (params.on) {
      for (var eventName in params.on) {
        instance.current.off(eventName);
        instance.current.on(eventName, params.on[eventName]);
      }
    }
  }

  return /*#__PURE__*/React.createElement("div", _extends({}, others, {
    className: "swiper-container".concat(others.className ? ' ' + others.className : ''),
    ref: rootRef
  }), /*#__PURE__*/React.createElement("div", _extends({}, wrapperAttribute, {
    className: "swiper-wrapper".concat(wrapperAttribute.className ? ' ' + wrapperAttribute.className : '')
  }), children), params.pagination && /*#__PURE__*/React.createElement("div", _extends({}, paginationAttribute, {
    className: "swiper-pagination".concat(paginationAttribute.className ? ' ' + paginationAttribute.className : '')
  })), params.navigation && params.navigation.prevEl && /*#__PURE__*/React.createElement("div", _extends({}, prevAttribute, {
    className: "swiper-button-prev".concat(prevAttribute.className ? ' ' + prevAttribute.className : '')
  })), params.navigation && params.navigation.nextEl && /*#__PURE__*/React.createElement("div", _extends({}, nextAttribute, {
    className: "swiper-button-next".concat(nextAttribute.className ? ' ' + nextAttribute.className : '')
  })), containerChildren);
});
